@@ -4,7 +4,7 @@ offsetdate <- function(ltraj, offset, units=c("sec", "min", "hour", "day"))
         stop("ltraj should be of class \"ltraj\"")
     if (!attr(ltraj,"typeII"))
         stop("ltraj should be of type II (time recorded)")
-
+    p4s <- .checkp4(ltraj)
     units <- match.arg(units)
     offset <- .convtime(offset, units)
 
@@ -19,5 +19,6 @@ offsetdate <- function(ltraj, offset, units=c("sec", "min", "hour", "day"))
     class(res) <- c("ltraj", "list")
     attr(res,"typeII") <- TRUE
     attr(res,"regular") <- is.regular(res)
+    attr(res,"proj4string") <- p4s
     return(res)
 }
